@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -77,5 +77,5 @@ class VideoNote(_BaseThumbedMedium):
         )
         with self._unfrozen():
             # Required
-            self.length = length
-            self.duration = duration
+            self.length: int = length
+            self.duration: int = duration
