@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,7 +17,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains the classes that represent Telegram InlineQueryResultGif."""
-from typing import TYPE_CHECKING, Sequence
+from typing import TYPE_CHECKING, Optional, Sequence, Tuple
 
 from telegram._inline.inlinekeyboardmarkup import InlineKeyboardMarkup
 from telegram._inline.inlinequeryresult import InlineQueryResult
@@ -130,21 +130,20 @@ class InlineQueryResultGif(InlineQueryResult):
         *,
         api_kwargs: JSONDict = None,
     ):
-
         # Required
         super().__init__(InlineQueryResultType.GIF, id, api_kwargs=api_kwargs)
         with self._unfrozen():
-            self.gif_url = gif_url
-            self.thumb_url = thumb_url
+            self.gif_url: str = gif_url
+            self.thumb_url: str = thumb_url
 
             # Optionals
-            self.gif_width = gif_width
-            self.gif_height = gif_height
-            self.gif_duration = gif_duration
-            self.title = title
-            self.caption = caption
-            self.parse_mode = parse_mode
-            self.caption_entities = parse_sequence_arg(caption_entities)
-            self.reply_markup = reply_markup
-            self.input_message_content = input_message_content
-            self.thumb_mime_type = thumb_mime_type
+            self.gif_width: Optional[int] = gif_width
+            self.gif_height: Optional[int] = gif_height
+            self.gif_duration: Optional[int] = gif_duration
+            self.title: Optional[str] = title
+            self.caption: Optional[str] = caption
+            self.parse_mode: ODVInput[str] = parse_mode
+            self.caption_entities: Tuple[MessageEntity, ...] = parse_sequence_arg(caption_entities)
+            self.reply_markup: Optional[InlineKeyboardMarkup] = reply_markup
+            self.input_message_content: Optional[InputMessageContent] = input_message_content
+            self.thumb_mime_type: Optional[str] = thumb_mime_type
