@@ -2,7 +2,7 @@
 # pylint: disable=redefined-builtin
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -109,6 +109,9 @@ class User(TelegramObject):
             the bot to the attachment menu.
 
             .. versionadded:: 20.0
+    .. |user_chat_id_note| replace:: This shortcuts build on the assumption that :attr:`User.id`
+        coincides with the :attr:`Chat.id` of the private chat with the user. This has been the
+        case so far, but Telegram does not guarantee that this stays this way.
     """
 
     __slots__ = (
@@ -143,18 +146,18 @@ class User(TelegramObject):
     ):
         super().__init__(api_kwargs=api_kwargs)
         # Required
-        self.id = id  # pylint: disable=invalid-name
-        self.first_name = first_name
-        self.is_bot = is_bot
+        self.id: int = id  # pylint: disable=invalid-name
+        self.first_name: str = first_name
+        self.is_bot: bool = is_bot
         # Optionals
-        self.last_name = last_name
-        self.username = username
-        self.language_code = language_code
-        self.can_join_groups = can_join_groups
-        self.can_read_all_group_messages = can_read_all_group_messages
-        self.supports_inline_queries = supports_inline_queries
-        self.is_premium = is_premium
-        self.added_to_attachment_menu = added_to_attachment_menu
+        self.last_name: Optional[str] = last_name
+        self.username: Optional[str] = username
+        self.language_code: Optional[str] = language_code
+        self.can_join_groups: Optional[bool] = can_join_groups
+        self.can_read_all_group_messages: Optional[bool] = can_read_all_group_messages
+        self.supports_inline_queries: Optional[bool] = supports_inline_queries
+        self.is_premium: Optional[bool] = is_premium
+        self.added_to_attachment_menu: Optional[bool] = added_to_attachment_menu
 
         self._id_attrs = (self.id,)
 
@@ -293,6 +296,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.pin_chat_message`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :obj:`bool`: On success, :obj:`True` is returned.
 
@@ -324,6 +330,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.unpin_chat_message`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :obj:`bool`: On success, :obj:`True` is returned.
 
@@ -354,6 +363,9 @@ class User(TelegramObject):
         For the documentation of the arguments, please see
         :meth:`telegram.Bot.unpin_all_chat_messages`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :obj:`bool`: On success, :obj:`True` is returned.
 
@@ -392,6 +404,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_message`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -442,6 +457,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_photo`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -493,6 +511,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_media_group`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             Tuple[:class:`telegram.Message`:] On success, a tuple of :class:`~telegram.Message`
             instances that were sent is returned.
@@ -546,6 +567,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_audio`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -591,6 +615,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_chat_action`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :obj:`True`: On success.
 
@@ -635,6 +662,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_contact`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -681,6 +711,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_dice`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -729,6 +762,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_document`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -777,6 +813,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_game`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -845,6 +884,9 @@ class User(TelegramObject):
             order of the arguments had to be changed. Use keyword arguments to make sure that the
             arguments are passed correctly.
 
+        Note:
+            |user_chat_id_note|
+
         .. versionchanged:: 13.5
             As of Bot API 5.2, the parameter
             :paramref:`start_parameter <telegram.Bot.send_invoice.start_parameter>` is optional.
@@ -917,6 +959,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_location`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -974,6 +1019,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_animation`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -1025,6 +1073,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_sticker`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -1077,6 +1128,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_video`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -1137,6 +1191,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_venue`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -1191,6 +1248,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_video_note`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -1242,6 +1302,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_voice`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -1300,6 +1363,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_poll`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -1357,6 +1423,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.copy_message`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -1407,6 +1476,9 @@ class User(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.copy_message`.
 
+        Note:
+            |user_chat_id_note|
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -1448,6 +1520,9 @@ class User(TelegramObject):
         For the documentation of the arguments, please see
         :meth:`telegram.Bot.approve_chat_join_request`.
 
+        Note:
+            |user_chat_id_note|
+
         .. versionadded:: 13.8
 
         Returns:
@@ -1481,6 +1556,9 @@ class User(TelegramObject):
         For the documentation of the arguments, please see
         :meth:`telegram.Bot.decline_chat_join_request`.
 
+        Note:
+            |user_chat_id_note|
+
         .. versionadded:: 13.8
 
         Returns:
@@ -1516,6 +1594,9 @@ class User(TelegramObject):
 
         .. seealso:: :meth:`get_menu_button`
 
+        Note:
+            |user_chat_id_note|
+
         .. versionadded:: 20.0
 
         Returns:
@@ -1549,6 +1630,9 @@ class User(TelegramObject):
 
         .. seealso:: :meth:`set_menu_button`
 
+        Note:
+            |user_chat_id_note|
+
         .. versionadded:: 20.0
 
         Returns:
